@@ -173,6 +173,10 @@ SV * newSVGtkMenuEntry(GtkMenuEntry * e)
 	return r;
 }
 
+SV * newSVGtkSelectionDataRef(GdkWindow * w) { return newSVMiscRef(w, "Gtk::SelectionData",0); }
+GdkWindow * SvGtkSelectionDataRef(SV * data) { return SvMiscRef(data, "Gtk::SelectionData"); }
+
+
 /*SV * newSVGtkMenuPath(GtkMenuPath * e)
 {
 	HV * h;
@@ -189,4 +193,4 @@ SV * newSVGtkMenuEntry(GtkMenuEntry * e)
 	hv_store(h, "widget", 6, newSVGtkObjectRef(e->widget, 0), 0);
 	return r;
 }
-*/
\ No newline at end of file
+*/
